@@ -31,6 +31,9 @@ class Pair(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def __hash__(self):
+        return id(self)
+
     def __str__(self):
         segments = [self.first.__str__()]
         elems = self.rest
