@@ -8,7 +8,7 @@ class Symbol(object):
         Get the interned symbol of name. If no found, create
         a new interned symbol.
         """
-        if cls.symbols.has_key(name):
+        if name in cls.symbols:
             return cls.symbols[name]
 
         sym = object.__new__(cls)
@@ -21,6 +21,9 @@ class Symbol(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def __hash__(self):
+        return id(self)
+
     def get_name(self):
         return self._name
     def set_name(self):
